#
# spec file for package slapi-nis
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define ldap_impl mozldap
%define betxn_opts --enable-be-txns-by-default

Name:           slapi-nis
Version:        0.56.1
Release:        lp150.1.2
Summary:        NIS Server and Schema Compatibility plugins for 389 Directory Server
License:        GPL-2.0
Group:          Productivity/Networking/LDAP/Servers
Url:            https://pagure.io/slapi-nis
Source0:        https://releases.pagure.org/slapi-nis/slapi-nis-%{version}.tar.gz
Source1:        https://releases.pagure.org/slapi-nis/slapi-nis-%{version}.tar.gz.sig
BuildRequires:  glibc-devel
BuildRequires:  libnsl-devel
BuildRequires:  pam-devel
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(dirsrv) >= 1.3.5.6
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(mozldap)
BuildRequires:  pkgconfig(nspr)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(sss_nss_idmap)
#BuildRequires: openldap2-devel
%define sss_nss_opts --with-sss-nss-idmap --with-idviews

%description
This package provides two plugins for 389 Directory Server.

The NIS Server plugin allows the directory server to act as a NIS server
for clients, dynamically generating and updating NIS maps according to
its configuration and the contents of the DIT, and serving the results to
clients using the NIS protocol as if it were an ordinary NIS server.

The Schema Compatibility plugin allows the directory server to provide an
alternate view of entries stored in part of the DIT, optionally adding,
dropping, or renaming attribute values, and optionally retrieving values
for attributes from multiple entries in the tree.

%prep
%setup -q

%build
%configure --disable-static --with-tcp-wrappers --with-ldap=%{ldap_impl} \
	--with-nsswitch --with-pam --with-pam-service=system-auth \
	%{sss_nss_opts} %{betxn_opts}
sed -i -e 's,%{_libdir}/dirsrv/plugins/,,g' -e 's,.so$,,g' doc/examples/*.ldif
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
rm %{buildroot}/%{_libdir}/dirsrv/plugins/*.la

%files
%defattr(-,root,root,-)
%doc COPYING NEWS README STATUS doc/*.txt doc/examples/*.ldif doc/ipa
%{_mandir}/man1/*
%{_libdir}/dirsrv/plugins/*.so
%{_sbindir}/nisserver-plugin-defs

%changelog
* Thu Aug 17 2017 kukuk@suse.de
- Add libnsl-devel build requires for glibc obsoleting libnsl
* Thu May 18 2017 mrueckert@suse.de
- update to 0.56.1
  - Support querying external users by UPN alias
  - Don't clobber target of the pblock for ID views
  - Add priming thread to populate the map cache without blocking
    the DS
  - Add support for changing passwords for users from a primary
    tree
  - requires DS 1.3.5.6 or later
* Thu Apr 14 2016 mrueckert@suse.de
- update to 0.55
  - Support external members of IPA groups in schema compat
  - Support bind over ID overrides when uid is not overridden
  - Populate schema compat trees in parallel to LDAP server startup
* Mon May 11 2015 jengelh@inai.de
- Use pkgconfig() symbols to request buildtime requirements
* Fri May  8 2015 hguo@suse.com
- Source extracted from Fedora 21 release SRPM, with minor adjustments.
